#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

import configparser
from datetime import datetime, timezone
from email.message import EmailMessage
import os
import pytz
import smtplib
import socket

RANDOM_SEED = 9823
DATE_FORMAT = "%Y%m%d-%H%M%S"

CONFIG_FILE_PATH = "conf/settings.ini"


def get_config():
    if not os.path.isfile(CONFIG_FILE_PATH):
        raise Exception(
            "Config file does not exist: {}".format(os.path.abspath(CONFIG_FILE_PATH))
        )

    configparse = configparser.ConfigParser(interpolation=None)
    configparse.read(CONFIG_FILE_PATH)
    return configparse


def send_email_notification(text="", subject=""):
    config = get_config()
    hostname = socket.gethostname()

    tz = pytz.timezone("US/Mountain")

    msg = EmailMessage()
    if len(subject) > 0:
        msg["Subject"] = subject
    else:
        msg["Subject"] = "Processing Complete on {}".format(hostname)

    msg["From"] = config["DEFAULT"]["EmailFromAddress"]
    msg["To"] = config["DEFAULT"]["EmailToAddress"]
    msg["Date"] = datetime.now(timezone.utc).strftime("%a, %m %b %Y %H:%M:%S %z")
    if len(text) > 0:
        msg.set_content(text)
    else:
        msg.set_content("Processing has completed on {}".format(hostname))

    s = smtplib.SMTP_SSL(config["DEFAULT"]["EmailSmtpServer"])
    s.login(
        config["DEFAULT"]["EmailFromAddress"], config["DEFAULT"]["EmailSmtpPassword"]
    )
    s.send_message(msg)
    s.quit()


def make_surrounded(s, surround_char="*", width=80):
    actual_width = width - 4
    format_string = "{} {{:{}}} {}".format(surround_char, actual_width, surround_char)
    return format_string.format(s)
