#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

import torch.nn as nn
from torchvision import transforms

try:
    from torchvision import models
except ImportError:
    models = None


model_names = ["resnet18", "resnet34", "resnet50", "resnet101", "resnet152"]
required_config_keys = []

criterion = nn.BCEWithLogitsLoss()
normalizing_vector = ([0.485, 0.456, 0.406], [0.229, 0.224, 0.225])
data_transforms = [transforms.ToTensor(), transforms.Normalize(*normalizing_vector)]


def get_model(model_name):
    num_classes = 1

    model_ft = None

    if model_name == "resnet18":
        model_ft = models.resnet18(weights="IMAGENET1K_V1")
    elif model_name == "resnet34":
        model_ft = models.resnet34(weights="IMAGENET1K_V1")
    elif model_name == "resnet50":
        model_ft = models.resnet50(weights="IMAGENET1K_V1")
    elif model_name == "resnet101":
        model_ft = models.resnet101(weights="IMAGENET1K_V1")
    elif model_name == "resnet152":
        model_ft = models.resnet152(weights="IMAGENET1K_V1")
    else:
        raise Exception("Invalid resnet model name given: {}".format(model_name))

    num_filters = model_ft.fc.in_features
    model_ft.fc = nn.Linear(num_filters, num_classes)

    return model_ft
