#
#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#
#
from collections import OrderedDict

from torch import nn
import torchvision


model_names = ["swin_t"]
required_config_keys = [
    "num_epochs",
    "model_name",
    "dataset_path",
    "batch_size",
    "random_seed",
    "force_cpu",
]

criterion = nn.BCEWithLogitsLoss()
# criterion = nn.BCELoss()
# criterion = nn.CrossEntropyLoss()
normalizing_vector = ([0.485, 0.456, 0.406], [0.229, 0.224, 0.225])
data_transforms = [
    torchvision.transforms.ToTensor(),
    torchvision.transforms.Normalize(*normalizing_vector),
]


def get_model(model_name):
    num_classes = 1
    model_ft = None

    if model_name == "swin_t":
        model_ft = torchvision.models.swin_t()
    else:
        raise Exception("Invalid model_name passed: {}".format(model_name))

    model = nn.Sequential(
        OrderedDict(
            [
                (model_name, model_ft),
                ("fc1", nn.Linear(model_ft.num_classes, num_classes)),
                #        ('sigmoid', nn.Sigmoid())
            ]
        )
    )

    return model
