#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

import torch.nn as nn
from torchvision import transforms

try:
    from torchvision import models
except ImportError:
    models = None


model_names = ["vgg11", "vgg13", "vgg16"]
required_config_keys = [
    "num_epochs",
    "model_name",
    "dataset_path",
    "batch_size",
    "random_seed",
    "force_cpu",
]

criterion = nn.BCEWithLogitsLoss()
normalizing_vector = ([0.485, 0.456, 0.406], [0.229, 0.224, 0.225])
data_transforms = [transforms.ToTensor(), transforms.Normalize(*normalizing_vector)]


def get_model(model_name):
    num_classes = 1
    model_ft = None

    if model_name == "vgg11":
        model_ft = models.vgg11(weights="IMAGENET1K_V1")
    elif model_name == "vgg13":
        model_ft = models.vgg13(weights="IMAGENET1K_V1")
    elif model_name == "vgg16":
        model_ft = models.vgg16(weights="IMAGENET1K_V1")
    else:
        raise Exception("Invalid model_name passed: {}".format(model_name))

    num_filters = model_ft.classifier[6].in_features
    model_ft.classifier[6] = nn.Linear(num_filters, num_classes)

    return model_ft
