#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

from collections import OrderedDict

from torch import nn
import torchvision

try:
    from torchvision import models as vision_models
except ImportError:
    vision_models = None


model_names = ["vit_b_16", "vit_b_32", "vit_l_16", "vit_l_32", "vit_h_14"]
required_config_keys = [
    "num_epochs",
    "model_name",
    "dataset_path",
    "batch_size",
    "random_seed",
    "force_cpu",
]

criterion = nn.BCEWithLogitsLoss()
# criterion = nn.BCELoss()
# criterion = nn.CrossEntropyLoss()
normalizing_vector = ([0.485, 0.456, 0.406], [0.229, 0.224, 0.225])
data_transforms = [
    torchvision.transforms.ToTensor(),
    torchvision.transforms.Normalize(*normalizing_vector),
]


def get_model(model_name):
    num_classes = 1
    model_ft = None

    if model_name == "vit_b_16":
        model_ft = torchvision.models.vit_b_16()
    elif model_name == "vit_b_32":
        model_ft = torchvision.models.vit_b_32()
    elif model_name == "vit_h_14":
        model_ft = torchvision.models.vit_h_14()
    else:
        raise Exception("Invalid model_name passed: {}".format(model_name))

    num_filters = model_ft.num_classes
    model = nn.Sequential(
        OrderedDict(
            [
                (model_name, model_ft),
                ("fc1", nn.Linear(num_filters, num_classes)),
                #        ('sigmoid', nn.Sigmoid())
            ]
        )
    )

    return model
