#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

import os
import re
import subprocess

import click


def get_gpu_memory(gpu_id):
    """
    Assumes that nvidia-smi is return values in MiB
    """
    command = (
        "nvidia-smi -i {} --query-gpu 'memory.free,memory.used' --format csv".format(
            gpu_id
        )
    )
    smiproc = subprocess.run(command, shell=True, capture_output=True)
    if smiproc.returncode != 0:
        raise Exception(
            "Ran nvidia-smi command, got non-zero return code: {}".format(
                smiproc.returncode
            )
        )

    smiout = smiproc.stdout.decode("utf-8")
    smi_lines = smiout.split("\n")
    memnum_re = re.compile(r"[0-9]+")
    freemem_match = memnum_re.findall(smi_lines[1])

    return int(freemem_match[0]), int(freemem_match[1])


@click.command()
def cli():
    gpu_id = 0
    print("Getting GPU {} information via nvidia-smi".format(gpu_id))

    freemem, usedmem = get_gpu_memory(gpu_id)
    print("GPU{} Free Memory: {} MiB".format(gpu_id, freemem))
    print("GPU{} Used Memory: {} MiB".format(gpu_id, usedmem))


if __name__ == "__main__":
    cli()
