#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

from datetime import datetime

from . import BaseClassifierTuner
from .. import RANDOM_SEED, DATE_FORMAT


# smaller grid search space
# tunables = {
#    'cnn1_output_channels': [6, 10],
#    'cnn2_output_channels': [15, 20],
#    'cnn3_output_channels': [12, 24],
#    'layer_1_size': [50, 100],
#    'kernel_size': [3],
#    'max_pool_kernel': [1, 2],
#    'max_pool_stride': [2],
# }


class CnnClassifierTuner(BaseClassifierTuner):
    def _init_base_config(self, force_cpu=False):
        screenshot_height, screenshot_width = self._detect_screenshot_size()

        self.tunables = {
            "cnn1_output_channels": [3, 6, 10],
            "cnn2_output_channels": [15, 20],
            "cnn3_output_channels": [6, 12],
            "layer_1_size": [50, 100],
            "kernel_size": [2, 3],
            "max_pool_kernel": [1, 2],
            "batch_size": [4, 16],
            "num_epochs": [2, 10, 15],
        }

        self.base_config = {
            "trainer_type": "torch",
            "cnn1_input_channels": 3,
            "layer_end_size": 1,
            "cnn_stride": 1,
            "max_pool_stride": 2,
            "image_height": screenshot_height,
            "image_width": screenshot_width,
            "force_cpu": force_cpu,
            "base_dir": self.base_dir,
            "random_seed": RANDOM_SEED,
            "mlflow_experiment_name": "OpenQA-rescheduler-tuning-{}".format(
                datetime.now().strftime(DATE_FORMAT)
            ),
            "dataset_path": self.dataset_path,
            "model_name": "cnn_3_layer",
        }
