#  -*- coding: utf-8 -*-
# Copyright (c) 2023 Timothy Flink.
# License: GPL-3.0-or-later
# See the LICENSE file for more details on licensing
#
# This file is part of openqa_classifier
# (see https://pagure.io/fedora-qa/openqa_classifier).
#

from datetime import datetime

from . import BaseClassifierTuner
from .. import RANDOM_SEED, DATE_FORMAT


class PretrainedClassifierTuner(BaseClassifierTuner):
    def _init_base_config(self, force_cpu=False):
        screenshot_height, screenshot_width = self._detect_screenshot_size()

        self.tunables = {
            "model_name": [
                "vgg11",
                "vgg13",
                "vgg16",
                "resnet18",
                "resnet34",
                "resnet50",
                "resnet101",
                "resnet152",
            ],
            "num_epochs": [5, 10, 15],
            "batch_size": [4, 16, 32],
        }

        self.base_config = {
            "trainer_type": "torch",
            "image_height": screenshot_height,
            "image_width": screenshot_width,
            "force_cpu": force_cpu,
            "base_dir": self.base_dir,
            "random_seed": RANDOM_SEED,
            "mlflow_experiment_name": "OpenQA-rescheduler-tuning-{}".format(
                datetime.now().strftime(DATE_FORMAT)
            ),
            "dataset_path": self.dataset_path,
        }
