import os

import click

from openqa_classifier import openqa


@click.command
@click.argument("job_file")
@click.option(
    "--base_dir", default="./openqa_data", help="base directory for downloaded data"
)
def download_openqa_job_data(job_file, base_dir):
    if not os.path.isfile(job_file):
        raise Exception("Input job file does not exist: {}".format(job_file))

    if not os.path.isdir(base_dir):
        print("output base dir does not exist, creating: {}".format(base_dir))
        os.makedirs(base_dir)

    jobids = []
    with open(job_file, "r") as jobfile:
        for line in jobfile:
            jobids.append(int(line))

    num_jobs = len(jobids)
    print("Read {} jobids from file {}".format(num_jobs, job_file))

    num_jobs_processed = 0
    for jobid in jobids:
        num_jobs_processed += 1
        print("Processing job {} ({}/{})".format(jobid, num_jobs_processed, num_jobs))
        output_dir = os.path.join(base_dir, str(jobid))
        if os.path.exists(output_dir):
            print("output dir for job {} already exists. skipping".format(jobid))
            continue
        #        else:
        #            os.makedirs(output_dir)

        print("Downloading data for job {}".format(jobid))

        gather = openqa.GatherOpenQAData(jobid, base_dir)

        gather.download_api_data()
        gather.download_logs_files()
        gather.download_screenshots()


if __name__ == "__main__":
    download_openqa_job_data()
